==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/TargetPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Group specific to the update configuration.
 * @property azureQueries List of Azure queries in the software update configuration.
 * @property nonAzureQueries List of non Azure queries in the software update configuration.
 */
public data class TargetPropertiesArgs(
    public val azureQueries: Output<List<AzureQueryPropertiesArgs>>? = null,
    public val nonAzureQueries: Output<List<NonAzureQueryPropertiesArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs =
        com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs.builder()
            .azureQueries(
                azureQueries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .nonAzureQueries(
                nonAzureQueries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [TargetPropertiesArgs].
 */
@PulumiTagMarker
public class TargetPropertiesArgsBuilder internal constructor() {
    private var azureQueries: Output<List<AzureQueryPropertiesArgs>>? = null

    private var nonAzureQueries: Output<List<NonAzureQueryPropertiesArgs>>? = null

    /**
     * @param value List of Azure queries in the software update configuration.
     */
    @JvmName("cyvahunjjmjrmooq")
    public suspend fun azureQueries(`value`: Output<List<AzureQueryPropertiesArgs>>) {
        this.azureQueries = value
    }

    @JvmName("yvkxadfibqaxqkwb")
    public suspend fun azureQueries(vararg values: Output<AzureQueryPropertiesArgs>) {
        this.azureQueries = Output.all(values.asList())
    }

    /**
     * @param values List of Azure queries in the software update configuration.
     */
    @JvmName("wrwvpuokasfjcfrv")
    public suspend fun azureQueries(values: List<Output<AzureQueryPropertiesArgs>>) {
        this.azureQueries = Output.all(values)
    }

    /**
     * @param value List of non Azure queries in the software update configuration.
     */
    @JvmName("iwmosilmqfpkscdh")
    public suspend fun nonAzureQueries(`value`: Output<List<NonAzureQueryPropertiesArgs>>) {
        this.nonAzureQueries = value
    }

    @JvmName("guwvromwhyvtghpp")
    public suspend fun nonAzureQueries(vararg values: Output<NonAzureQueryPropertiesArgs>) {
        this.nonAzureQueries = Output.all(values.asList())
    }

    /**
     * @param values List of non Azure queries in the software update configuration.
     */
    @JvmName("vytwukxauexnnqii")
    public suspend fun nonAzureQueries(values: List<Output<NonAzureQueryPropertiesArgs>>) {
        this.nonAzureQueries = Output.all(values)
    }

    /**
     * @param value List of Azure queries in the software update configuration.
     */
    @JvmName("iiojgqfulhlkblvu")
    public suspend fun azureQueries(`value`: List<AzureQueryPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureQueries = mapped
    }

    /**
     * @param argument List of Azure queries in the software update configuration.
     */
    @JvmName("ccijykoxhjawdkpb")
    public suspend
    fun azureQueries(argument: List<suspend AzureQueryPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.azureQueries = mapped
    }

    /**
     * @param argument List of Azure queries in the software update configuration.
     */
    @JvmName("eclkcysgqcyvvkvl")
    public suspend fun azureQueries(
        vararg
        argument: suspend AzureQueryPropertiesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            AzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.azureQueries = mapped
    }

    /**
     * @param argument List of Azure queries in the software update configuration.
     */
    @JvmName("kxamkxnvstvtsmgl")
    public suspend fun azureQueries(argument: suspend AzureQueryPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(AzureQueryPropertiesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.azureQueries = mapped
    }

    /**
     * @param values List of Azure queries in the software update configuration.
     */
    @JvmName("wwcshoicasabfghy")
    public suspend fun azureQueries(vararg values: AzureQueryPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azureQueries = mapped
    }

    /**
     * @param value List of non Azure queries in the software update configuration.
     */
    @JvmName("gsyhmteccfrhjisi")
    public suspend fun nonAzureQueries(`value`: List<NonAzureQueryPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nonAzureQueries = mapped
    }

    /**
     * @param argument List of non Azure queries in the software update configuration.
     */
    @JvmName("kelwgtfjifkgwtrm")
    public suspend
    fun nonAzureQueries(argument: List<suspend NonAzureQueryPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            NonAzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.nonAzureQueries = mapped
    }

    /**
     * @param argument List of non Azure queries in the software update configuration.
     */
    @JvmName("dakqtyjhswhkdadi")
    public suspend fun nonAzureQueries(
        vararg
        argument: suspend NonAzureQueryPropertiesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            NonAzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.nonAzureQueries = mapped
    }

    /**
     * @param argument List of non Azure queries in the software update configuration.
     */
    @JvmName("rqpteelpvgbedarv")
    public suspend
    fun nonAzureQueries(argument: suspend NonAzureQueryPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            NonAzureQueryPropertiesArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.nonAzureQueries = mapped
    }

    /**
     * @param values List of non Azure queries in the software update configuration.
     */
    @JvmName("oosrflieeawfmfum")
    public suspend fun nonAzureQueries(vararg values: NonAzureQueryPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nonAzureQueries = mapped
    }

    internal fun build(): TargetPropertiesArgs = TargetPropertiesArgs(
        azureQueries = azureQueries,
        nonAzureQueries = nonAzureQueries,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/TargetPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Group specific to the update configuration.
 * @property azureQueries List of Azure queries in the software update configuration.
 * @property nonAzureQueries List of non Azure queries in the software update configuration.
 */
public data class TargetPropertiesArgs(
    public val azureQueries: Output<List<AzureQueryPropertiesArgs>>? = null,
    public val nonAzureQueries: Output<List<NonAzureQueryPropertiesArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs =
        com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs.builder()
            .azureQueries(
                azureQueries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .nonAzureQueries(
                nonAzureQueries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [TargetPropertiesArgs].
 */
@PulumiTagMarker
public class TargetPropertiesArgsBuilder internal constructor() {
    private var azureQueries: Output<List<AzureQueryPropertiesArgs>>? = null

    private var nonAzureQueries: Output<List<NonAzureQueryPropertiesArgs>>? = null

    /**
     * @param value List of Azure queries in the software update configuration.
     */
    @JvmName("fqwmjyckxljsronw")
    public suspend fun azureQueries(`value`: Output<List<AzureQueryPropertiesArgs>>) {
        this.azureQueries = value
    }

    @JvmName("opcnnotsphlfvyas")
    public suspend fun azureQueries(vararg values: Output<AzureQueryPropertiesArgs>) {
        this.azureQueries = Output.all(values.asList())
    }

    /**
     * @param values List of Azure queries in the software update configuration.
     */
    @JvmName("ioegiunhmkhuglhi")
    public suspend fun azureQueries(values: List<Output<AzureQueryPropertiesArgs>>) {
        this.azureQueries = Output.all(values)
    }

    /**
     * @param value List of non Azure queries in the software update configuration.
     */
    @JvmName("oldhkixatqharvkp")
    public suspend fun nonAzureQueries(`value`: Output<List<NonAzureQueryPropertiesArgs>>) {
        this.nonAzureQueries = value
    }

    @JvmName("wmgmekocvyyrkyat")
    public suspend fun nonAzureQueries(vararg values: Output<NonAzureQueryPropertiesArgs>) {
        this.nonAzureQueries = Output.all(values.asList())
    }

    /**
     * @param values List of non Azure queries in the software update configuration.
     */
    @JvmName("virytvivyhbfeyxo")
    public suspend fun nonAzureQueries(values: List<Output<NonAzureQueryPropertiesArgs>>) {
        this.nonAzureQueries = Output.all(values)
    }

    /**
     * @param value List of Azure queries in the software update configuration.
     */
    @JvmName("cegfbpgprjuojjuw")
    public suspend fun azureQueries(`value`: List<AzureQueryPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureQueries = mapped
    }

    /**
     * @param argument List of Azure queries in the software update configuration.
     */
    @JvmName("uqwirhparlbduvst")
    public suspend
    fun azureQueries(argument: List<suspend AzureQueryPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.azureQueries = mapped
    }

    /**
     * @param argument List of Azure queries in the software update configuration.
     */
    @JvmName("ashspkifmmkqvgrr")
    public suspend fun azureQueries(
        vararg
        argument: suspend AzureQueryPropertiesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            AzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.azureQueries = mapped
    }

    /**
     * @param argument List of Azure queries in the software update configuration.
     */
    @JvmName("sbssnbiounjrkjlp")
    public suspend fun azureQueries(argument: suspend AzureQueryPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(AzureQueryPropertiesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.azureQueries = mapped
    }

    /**
     * @param values List of Azure queries in the software update configuration.
     */
    @JvmName("hxoqyuovrfvaherc")
    public suspend fun azureQueries(vararg values: AzureQueryPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azureQueries = mapped
    }

    /**
     * @param value List of non Azure queries in the software update configuration.
     */
    @JvmName("ifgosdehhmmdmdju")
    public suspend fun nonAzureQueries(`value`: List<NonAzureQueryPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nonAzureQueries = mapped
    }

    /**
     * @param argument List of non Azure queries in the software update configuration.
     */
    @JvmName("xgcmsxegdwmcbtds")
    public suspend
    fun nonAzureQueries(argument: List<suspend NonAzureQueryPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            NonAzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.nonAzureQueries = mapped
    }

    /**
     * @param argument List of non Azure queries in the software update configuration.
     */
    @JvmName("dojnudywlsgjunet")
    public suspend fun nonAzureQueries(
        vararg
        argument: suspend NonAzureQueryPropertiesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            NonAzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.nonAzureQueries = mapped
    }

    /**
     * @param argument List of non Azure queries in the software update configuration.
     */
    @JvmName("gpnmfhfgcijedsic")
    public suspend
    fun nonAzureQueries(argument: suspend NonAzureQueryPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            NonAzureQueryPropertiesArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.nonAzureQueries = mapped
    }

    /**
     * @param values List of non Azure queries in the software update configuration.
     */
    @JvmName("owiqubkandiphloc")
    public suspend fun nonAzureQueries(vararg values: NonAzureQueryPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nonAzureQueries = mapped
    }

    internal fun build(): TargetPropertiesArgs = TargetPropertiesArgs(
        azureQueries = azureQueries,
        nonAzureQueries = nonAzureQueries,
    )
}
